<?php
/**
 * Template for displaying Author Archive pages
 *
 * @package WordPress
 * @subpackage Twenty_Eleven
 * @since Twenty Eleven 1.0
 */

get_header(); ?>

    <div id="primary" class="content-area">

        <!-- This sets the $curauth variable -->

		<?php
		$curauth         = ( isset( $_GET['author_name'] ) ) ? get_user_by( 'slug', $author_name ) : get_userdata( intval( $author ) );
		$avatar_full_url = esc_url( get_avatar_url( $curauth->ID ) );
		$avatar_url      = explode( "?", $avatar_full_url );

		$user_url  = $curauth->user_url;
		$user_info = nl2br( get_the_author_meta( 'description' ) );
		$small     = substr( $user_info, 0, 150 );
		?>

        <h2>About: <?php echo esc_html( $curauth->nickname, "auctor" ); ?></h2>
        <header class="entry-header">
            <div class="entry-author author-main">
                <div class="author-avatar">
                    <img src="<?php echo esc_url( $avatar_url[0], 'auctor' ) . "?s=300"; ?>"
                         class="avatar avatar-32 photo">

                </div>
                <div class="author-details">
                    <ul>
                        <li><strong>Name :</strong><span><?php echo esc_html( $curauth->display_name, "auctor" ); ?></span></li>
                        <li><strong>Email :</strong><span><?php echo esc_attr( $curauth->user_email, "auctor" ); ?></span></li>
						<?php if ( ! empty( $user_url ) ) { ?>
                            <li><strong>Website :</strong><span><?php echo esc_url( $user_url, "auctor" ); ?></span></li><?php } ?>
						<?php if ( ! empty( $user_info ) ) { ?>
                            <li><strong>Biographical Info :</strong><span><?php echo esc_html( $small, "auctor" ); ?></span></li><?php } ?>
                    </ul>
                </div>
            </div>
        </header>

        <h2>Posts by <?php echo esc_html( $curauth->nickname, "auctor" ); ?>:</h2>

        <ul class="blog-list row">
            <!-- The Loop -->

			<?php if ( have_posts() ) : while ( have_posts() ) : the_post();

				$post_id   = get_the_id();
				$post_data = get_post( $post_id );

				?>
                <li <?php post_class( 'col-sm-12' ); ?>>
                    <div class="blog-containe box-shadow ">
                        <div class="blog-img col-sm-6 col-xs-12">
							<?php
							$thumbnail_id  = get_post_thumbnail_id( $post_data->ID );
							$thumbnail_url = wp_get_attachment_image_src( $thumbnail_id, 'thumbnail-size', true );
							$default_image = get_template_directory_uri() . "/images/default-banner.png";

							if ( ! empty( $thumbnail_id ) ) {
								?>
								<?php echo the_post_thumbnail();
							} else { ?>
                                <img class="expert-img" src="<?php echo esc_html( $default_image, "auctor" ); ?>"
                                     alt="img"><?php
							} ?>
                        </div>
                        <div class="blog-details col-sm-6 col-xs-12">

							<?php
							//  set date formatting
							$date_format_feature = $post_data->post_date;
							$date                = date_create( $date_format_feature );
							$date_format         = date_format( $date, 'M d, Y' );
							$author              = get_the_author();
							$avatar              = get_avatar( $post_data->post_author, 32 );
							$avatar_full_url     = esc_url( get_avatar_url( $post_data->post_author ) );
							$avatar_url          = explode( "?", $avatar_full_url );
							?>

                            <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                            <span class="sub-title"> <img
                                        src="<?php echo esc_url( $avatar_url[0], 'auctor' ) . "?s=200"; ?>"
                                        class="avatar avatar-32 photo"> By <?php echo the_author_posts_link(); ?></span>

                            <div class="comment-sec">
                                <ul>
                                    <li><i class="fa fa-comments"
                                           aria-hidden="true"></i><?php echo esc_html( $post_data->comment_count, "auctor" ); ?>
                                    </li>
                                    <li><i class="fa fa-calendar"
                                           aria-hidden="true"></i><?php echo esc_html( $date_format, "auctor" ); ?></li>
                                </ul>
                            </div>
                            <div class="hover-item">
								<?php
								$big   = wp_strip_all_tags( get_the_excerpt(), true );
								$small = substr( $big, 0, 150 );
								?>
                                <p><?php echo esc_html( $small, "auctor" ) ?></p>
                                <div class="read-more"><a
                                            href="<?php echo esc_url( get_permalink( $post_data->ID ), "auctor" ); ?>">Read
                                        More</a></div>
                            </div>
                        </div>
                    </div>
                </li>
			<?php endwhile;
			else: ?>
                <p><?php esc_html( 'No posts by this author.' ); ?></p>

			<?php endif; ?>

            <!-- End Loop -->

        </ul>
    </div>
<?php get_sidebar(); ?>
<?php get_footer(); ?>